==> inteltime-1.0.0.tar.gz: inteltime-1.0.0/setup.py <==
import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

data_files = [
    (root, [os.path.join(root, f) for f in files])
        for root, dirs, files in os.walk('examples')
]

setup(
    name='inteltime',
    version='1.0.0',
    description="Intel checkpoint and cycle calculator for Niantic Lab's Ingress(tm)",
    long_description=long_description,
    author='Paul Traina',
    author_email='bulk+pypi@pst.org',
    packages=find_packages(exclude=['examples', 'tests']),
    entry_points = {
        'console_scripts': [
            'inteltime=inteltime.test:main',
            'inteltime-flask=inteltime.flask:main'
        ]
    },
    install_requires=[
        'python-dateutil',
        'timestring',
        'tzlocal'
    ],
    include_package_data=True,
    package_data={
        'inteltime': ['templates/*', 'examples/*', 'static/*']
    },
    data_files=data_files,
    zip_safe=False,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Console',
        'Environment :: Web Environment',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Natural Language :: English',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Database :: Front-Ends',
        'Topic :: Games/Entertainment',
    ],
    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },
)

==> inteltime-1.0.1.tar.gz: inteltime-1.0.1/setup.py <==
import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

data_files = [
    (root, [os.path.join(root, f) for f in files])
        for root, dirs, files in os.walk('examples')
]

setup(
    name='inteltime',
    version='1.0.1',
    description="Intel checkpoint and cycle calculator for Niantic Lab's Ingress(tm)",
    long_description=long_description,
    author='Paul Traina',
    author_email='bulk+pypi@pst.org',
    packages=find_packages(exclude=['examples', 'tests']),
    entry_points = {
        'console_scripts': [
            'inteltime=inteltime.test:main',
            'inteltime-flask=inteltime.flask:main'
        ]
    },
    install_requires=[
        'python-dateutil',
        'timestring',
        'tzlocal'
    ],
    include_package_data=True,
    package_data={
        'inteltime': ['templates/*', 'examples/*', 'static/*']
    },
    data_files=data_files,
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Environment :: Web Environment',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Natural Language :: English',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Database :: Front-Ends',
        'Topic :: Games/Entertainment',
    ],
    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },
)
